summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneystatement.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneystatement.cpp')
-rw-r--r--kmymoney2/mymoney/mymoneystatement.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/mymoney/mymoneystatement.cpp b/kmymoney2/mymoney/mymoneystatement.cpp
index 3756520..14df720 100644
--- a/kmymoney2/mymoney/mymoneystatement.cpp
+++ b/kmymoney2/mymoney/mymoneystatement.cpp
@@ -142,7 +142,7 @@ bool MyMoneyStatement::read(const TQDomElement& _e)
m_accountId = _e.attribute("accountid");
m_skipCategoryMatching = _e.attribute("skipCategoryMatching");
- int i = kAccountTypeTxt.tqfindIndex(_e.attribute("type",kAccountTypeTxt[1]));
+ int i = kAccountTypeTxt.findIndex(_e.attribute("type",kAccountTypeTxt[1]));
if ( i != -1 )
m_eType = static_cast<EType>(i);
@@ -162,7 +162,7 @@ bool MyMoneyStatement::read(const TQDomElement& _e)
t.m_strPayee = c.attribute("payee");
t.m_strBankID = c.attribute("bankid");
t.m_reconcile = static_cast<MyMoneySplit::reconcileFlagE>(c.attribute("reconcile").toInt());
- int i = kActionText.tqfindIndex(c.attribute("action",kActionText[1]));
+ int i = kActionText.findIndex(c.attribute("action",kActionText[1]));
if ( i != -1 )
t.m_eAction = static_cast<Transaction::EAction>(i);
@@ -219,7 +219,7 @@ bool MyMoneyStatement::read(const TQDomElement& _e)
bool MyMoneyStatement::isStatementFile(const TQString& _filename)
{
// filename is considered a statement file if it tqcontains
// the tag "<KMYMONEY2-STATEMENT>" in the first 20 lines.
bool result = false;
@@ -230,7 +230,7 @@ bool MyMoneyStatement::isStatementFile(const TQString& _filename)
int lineCount = 20;
while ( !ts.atEnd() && !result && lineCount != 0) {
- if ( ts.readLine().tqcontains("<KMYMONEY-STATEMENT>",false) )
+ if ( ts.readLine().contains("<KMYMONEY-STATEMENT>",false) )
result = true;
--lineCount;
}
@@ -219,7 +219,7 @@ bool MyMoneyStatement::read(const TQDomElement& _e)
bool MyMoneyStatement::isStatementFile(const TQString& _filename)
{
- // filename is considered a statement file if it tqcontains
+ // filename is considered a statement file if it contains
// the tag "<KMYMONEY2-STATEMENT>" in the first 20 lines.
bool result = false;